@@ -1,5 +1,6 @@
 /*
- * LALFrameVCSInfo.h - LALFrame VCS Information Header
+ * Copyright (C) 2014, 2016 Karl Wette
+ * Copyright (C) 2009-2013 Adam Mercer
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,9 +16,10 @@
  * along with with program; see the file COPYING. If not, write to the
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  * MA 02111-1307 USA
- *
- * Copyright (C) 2009-2013 Adam Mercer
- * Copyright (C) 2014 Karl Wette
+ */
+
+/*
+ * LALFrameVCSInfo.h - LALFrame VCS Information Header
  */
 
 /** \cond DONT_DOXYGEN */
@@ -33,37 +35,19 @@
 extern "C" {
 #endif
 
-/* VCS information defines */
-#define LALFRAME_NAME "LALFrame"
-#define LALFRAME_VCS_ID "a1664d2de7910a01819d19ba13160d191d4391a4"
-#define LALFRAME_VCS_DATE "2016-10-10 17:31:34 +0000"
+/* VCS information */
+#define LALFRAME_VCS_ID "52242fe66d70be95119035acb4cd97cc40ecfa3c"
+#define LALFRAME_VCS_DATE "2017-02-6 18:15:57 +0000"
 #define LALFRAME_VCS_BRANCH "None"
-#define LALFRAME_VCS_TAG "lalframe-v1.4.2"
+#define LALFRAME_VCS_TAG "lalframe-v1.4.3"
 #define LALFRAME_VCS_AUTHOR "Adam Mercer <adam.mercer@ligo.org>"
 #define LALFRAME_VCS_COMMITTER "Adam Mercer <adam.mercer@ligo.org>"
+#define LALFRAME_VCS_CLEAN "CLEAN"
 #define LALFRAME_VCS_STATUS "CLEAN: All modifications committed"
 
-/* Identable VCS information defines */
-#define LALFRAME_VCS_IDENT_ID "$" "LALFrameId: a1664d2de7910a01819d19ba13160d191d4391a4 " "$"
-#define LALFRAME_VCS_IDENT_DATE "$" "LALFrameDate: 2016-10-10 17:31:34 +0000 " "$"
-#define LALFRAME_VCS_IDENT_BRANCH "$" "LALFrameBranch: None " "$"
-#define LALFRAME_VCS_IDENT_TAG "$" "LALFrameTag: lalframe-v1.4.2 " "$"
-#define LALFRAME_VCS_IDENT_AUTHOR "$" "LALFrameAuthor: Adam Mercer <adam.mercer@ligo.org> " "$"
-#define LALFRAME_VCS_IDENT_COMMITTER "$" "LALFrameCommitter: Adam Mercer <adam.mercer@ligo.org> " "$"
-#define LALFRAME_VCS_IDENT_STATUS "$" "LALFrameStatus: CLEAN: All modifications committed " "$"
-
-/* Header VCS information structure */
-static const LALVCSInfo lalFrameVCSInfoHeader = { \
-  LALFRAME_NAME, \
-  LALFRAME_VERSION, \
-  LALFRAME_VCS_ID, \
-  LALFRAME_VCS_DATE, \
-  LALFRAME_VCS_BRANCH, \
-  LALFRAME_VCS_TAG, \
-  LALFRAME_VCS_AUTHOR, \
-  LALFRAME_VCS_COMMITTER, \
-  LALFRAME_VCS_STATUS \
-};
+/* VCS header/library mismatch link check function */
+#define LALFRAME_VCS_LINK_CHECK LALFRAME_CLEAN_52242fe66d70be95119035acb4cd97cc40ecfa3c_VCS_HEADER_LIBRARY_MISMATCH
+void LALFRAME_VCS_LINK_CHECK(void);
 
 #ifdef __cplusplus
 }
@@ -72,7 +56,3 @@ static const LALVCSInfo lalFrameVCSInfoHeader = { \
 #endif /* _LALFRAMEVCSINFOHEADER_H */
 
 /** \endcond */
-
-/*
- * vim: tw=0 ts=2 et
- */
